@@ -220,7 +220,7 @@ ODOO_MSGS = {
         CHECK_DESCRIPTION,
     ),
     "W8125": (
-        'The file "%s" is duplicated %d times from manifest key "%s"',
+        'The file "%s" is duplicated in lines %s from manifest key "%s"',
         "manifest-data-duplicated",
         CHECK_DESCRIPTION,
     ),
@@ -987,17 +987,27 @@ class OdooAddons(OdooBaseChecker, BaseChecker):
         # Check if resource exist
         # Check manifest-data-duplicated
         dirname = os.path.dirname(self.linter.current_file)
-        for key in misc.MANIFEST_DATA_KEYS:
+        for key in set(misc.MANIFEST_DATA_KEYS) & set(manifest_dict.keys()):
+            list_node = node.getitem(manifest_keys_nodes.get(key))
+            fname_str_nodes = defaultdict(list)
+            for str_node in getattr(list_node, "elts", []):
+                fname_str_nodes[str_node.value].append(str_node)
             for resource, coincidences in Counter(manifest_dict.get(key) or []).items():
+                fname_str_node = (
+                    fname_str_nodes.get(resource)[0] if len(fname_str_nodes.get(resource) or []) >= 1 else node
+                )
                 if coincidences >= 2:
+                    lines_str = ", ".join(
+                        f"{fname_str_node.lineno}" for fname_str_node in (fname_str_nodes.get(resource) or [])[1:]
+                    )
                     self.add_message(
                         "manifest-data-duplicated",
-                        node=manifest_keys_nodes.get(key) or node,
-                        args=(resource, coincidences, key),
+                        node=fname_str_node,
+                        args=(resource, lines_str, key),
                     )
                 if os.path.isfile(os.path.join(dirname, resource)):
                     continue
-                self.add_message("resource-not-exist", node=manifest_keys_nodes.get(key) or node, args=(key, resource))
+                self.add_message("resource-not-exist", node=fname_str_node, args=(key, resource))
                 # Check missing readme
 
         if not any(os.path.isfile(os.path.join(dirname, readme)) for readme in misc.README_FILES):
